@@ -1,5 +1,6 @@
 from .request.criar_boleto import CriarBoleto
 from .request.busca_boleto import BuscaBoleto
+from .request.numero_doc import NumeroDoc
 
 
 class PlugBoleto(object):
@@ -15,6 +16,9 @@ class PlugBoleto(object):
 
         return request.execute(criar_boleto)
 
+    def gerar_nossonumero(self):
+        request = NumeroDoc(None, self.environment)
+
     def consulta_boleto(self, id_integracao):
         request = BuscaBoleto(self.authorize, self.environment)
 
